﻿-------------------------------------------------------------------------------
-- SilentSendAddonMessage.lua
--
-- A simple hook into the SendAddonMessage API
-- to keep it from generating error messages for bad channels
-- such as "you are not in a guild" and "no such player as 'player' is online"
--
-- This is intended to hide the issue of interrupted data transfers
-- when sending a queue of data in whispers to a player who goes offline.
-- or when leaving guild during a similar bulk data transfer
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- INIT
-------------------------------------------------------------------------------

local _G = _G
local VERSION = 1 -- Dec 3, 2009

-- only load once
if _G.SilentSendAddonMessage then
	return
end

-- create
_G.SilentSendAddonMessage = {}
_G.SilentSendAddonMessage.version = VERSION -- for future use


-------------------------------------------------------------------------------
-- THE SILENCER FUNCTION
-------------------------------------------------------------------------------


_G.SilentSendAddonMessage.func = function ( prefix, text, chattype, target )
	if chattype == "WHISPER" and not UnitIsConnected( target) then
		--print("SilentSendAddonMessage: player is not online:"..target)
		return
	elseif chattype == "GUILD" and not IsInGuild() then
		--print("SilentSendAddonMessage: you're not in a guild")
		return
	else
		return SilentSendAddonMessage.Orig_SendAddonMessage( prefix, text, chattype, target )
	end
end


-------------------------------------------------------------------------------
-- REPLACE global SendAddonMessage with our silent version
-------------------------------------------------------------------------------

-- hooksecurefunc would call our function AFTER the original function
-- but we need to be called first, so we can abort the original call

_G.SilentSendAddonMessage.Orig_SendAddonMessage = _G.SendAddonMessage
_G.SendAddonMessage = SilentSendAddonMessage.func



-------------------------------------------------------------------------------
-- FOR FUTURE USE
-------------------------------------------------------------------------------

-- sample code and notes 
-- for reference purposes in case blizzard changes it on us

-- Currently (WoW 3.2.2) the party, raid, and battleground channels 
-- do not generate error messages from the blizzard API, 
-- even if they are invalid channels, i.e. because you left the group
-- so we don't bother to validate those channels in the simpler function above

-- the table-driven function below seemed slightly slower 
-- and it's unnecessary since the group channels don't show error messages

--[[


local SAFETYCHECKS = {

["WHISPER"]		= function( t ) 
	--NOTE: no handling here for error from attempting cross-faction, 
	-- but that's not something that will change in the middle of processing a queue
	return UnitIsConnected( t ) 
end,

["GUILD"]		= function( t ) 
	return IsInGuild() 
end,

["PARTY"]		= function( t ) 
	-- GetNumRealPartyMembers() > 1
	-- WoW 3.2.2 is silent on this error, so we can just allow it
	return true 
end,

["RAID"]		= function( t ) 
	-- GetNumRealRaidMembers() > 1
	-- WoW 3.2.2 is silent on this error, so we can just allow it
	return true 
end,

["BATTLEGROUND"]= function( t ) 
	-- this check would require a loop to correctly detect prep time
	-- WoW 3.2.2 is silent on this error, so we can just allow it
	return true
end,

} -- end SAFETYCHECKS


_G.SilentSendAddonMessage.func = function ( prefix, text, chattype, target )
    if not SAFETYCHECKS[ chattype ]( target ) then
        print("SilentSendAddonMessage: bad target: "..tostring(target or chattype) )
        return
    end
    return SilentSendAddonMessage.Orig_SendAddonMessage( prefix, text, chattype, target )
end


--]]
